@@ -38,7 +38,7 @@ function(var,infile,outfile,nc34=3){
    v__FillValue = "undefined"
    v_missing_value = "undefined"
 
-   info = "Created with the CM SAF R toolbox." 
+   info = "Created with the CM SAF R Toolbox." 
    var_prec="float"
 
    att_list <- c("standard_name","long_name","units","_FillValue","missing_value","calendar")
@@ -88,6 +88,15 @@ function(var,infile,outfile,nc34=3){
   # get information about variables
 	
   varnames <- names(id$var)
+  var_default <- subset(varnames, !(varnames %in% c("lat","lon","time_bnds","nb2","time")))
+  
+  if (toupper(var) %in% toupper(var_default)){
+    var <- var_default[which(toupper(var)==toupper(var_default))]
+  } else {
+      cat("Variable ",var," not found.",sep="","\n")
+      var <- var_default[1]
+      cat("Variable ",var," will be used.",sep="","\n")
+    }
 
    if (var %in% varnames){
     for (i in 1:6){
@@ -96,15 +105,15 @@ function(var,infile,outfile,nc34=3){
 	      assign(v_att_list[i],att_dum$value)}
     }
 
-      # get details of file
+    # get details of file
 
-	lon <- ncvar_get(id,lon_name)
-	lat <- ncvar_get(id,lat_name)
-	time1 <- ncvar_get(id,t_name)
-	time_len <- length(time1)
-	if ("time_bnds" %in% varnames){
-	  tbnds1 <- ncvar_get(id,"time_bnds")
-	}
+	  lon <- ncvar_get(id,lon_name)
+	  lat <- ncvar_get(id,lat_name)
+	  time1 <- ncvar_get(id,t_name)
+	  time_len <- length(time1)
+	  if ("time_bnds" %in% varnames){
+	    tbnds1 <- ncvar_get(id,"time_bnds")
+  	}
    }else{
       nc_close(id)
       stop(cat(paste("Variable ",var," not found! File contains: ",varnames,sep="")),"\n")}
@@ -153,12 +162,12 @@ function(var,infile,outfile,nc34=3){
   count <- 1
   for (i in 1:test_count){
       mon_dummy <- which(mul==test[i+1])
-	if (length(mon_dummy)>=1){
-	  time_bnds[1,count] <- time1[min(mon_dummy)]
-	  time_bnds[2,count] <- time1[max(mon_dummy)]
-	  count <- count+1
-	}
-   }
+	  if (length(mon_dummy)>=1){
+	    time_bnds[1,count] <- time1[min(mon_dummy)]
+	    time_bnds[2,count] <- time1[max(mon_dummy)]
+	    count <- count+1
+	  }
+  }
 
 # create netcdf
 
@@ -174,6 +183,7 @@ function(var,infile,outfile,nc34=3){
     compression = NA
   }
 
+    cmsaf_info <- (paste("cmsaf::dayrange for variable ",var,sep=""))
     target[is.na(target)] <- v_missing_value
 
     nb2 <- c(0,1)
@@ -195,6 +205,7 @@ function(var,infile,outfile,nc34=3){
 
     ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
     ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
+    ncatt_put(ncnew,var,"cmsaf_info",cmsaf_info,prec="text")
 
     ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
     ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -217,22 +228,22 @@ function(var,infile,outfile,nc34=3){
   count <- 1
   for (i in 1:test_count){
       day_dummy <- which(mul==test[i+1])
-	if (length(day_dummy)>=1){
-	  startt <- min(dummy_vec[day_dummy])
-	  countt <- length(day_dummy)
-	  dum_dat <- ncvar_get(id,var,start=c(1,1,startt),count=c(-1,-1,countt),collapse_degen=FALSE)
-	  cat("\r","determine diurnal range ",count," of ",test_count,sep="")
-	  day_data <- apply(dum_dat,1:2,'range')
-	  dummy[,,1] <- day_data[2,,]-day_data[1,,]
-	  day_data <- dummy
-	  day_data[is.na(day_data)] <- v_missing_value
-	  ncvar_put(ncnew,var1,day_data,start=c(1,1,count),count=c(-1,-1,1))
-	  ncvar_put(ncnew,t,times[i], start=count, count=1)
-	  ncvar_put(ncnew,var2,time_bnds[,i],start=c(1,count),count=c(-1,1))
-	  count <- count+1
-	}else {
+	  if (length(day_dummy)>=1){
+	    startt <- min(dummy_vec[day_dummy])
+	    countt <- length(day_dummy)
+	    dum_dat <- ncvar_get(id,var,start=c(1,1,startt),count=c(-1,-1,countt),collapse_degen=FALSE)
+	    cat("\r","determine diurnal range ",count," of ",test_count,sep="")
+	    day_data <- apply(dum_dat,1:2,'range')
+	    dummy[,,1] <- day_data[2,,]-day_data[1,,]
+	    day_data <- dummy
+	    day_data[is.na(day_data)] <- v_missing_value
+	    ncvar_put(ncnew,var1,day_data,start=c(1,1,count),count=c(-1,-1,1))
+	    ncvar_put(ncnew,t,times[i], start=count, count=1)
+	    ncvar_put(ncnew,var2,time_bnds[,i],start=c(1,count),count=c(-1,1))
+	    count <- count+1
+	  }else {
 	   cat("length of daily data not sufficient", "\n")}
-   }
+  }
  nc_close(id)
 
  nc_close(ncnew)
