@@ -38,7 +38,7 @@ function(var,infile,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
    v__FillValue = "undefined"
    v_missing_value = "undefined"
 
-   info = "Created with the CM SAF R toolbox." 
+   info = "Created with the CM SAF R Toolbox." 
    var_prec="float"
 
    att_list <- c("standard_name","long_name","units","_FillValue","missing_value","calendar")
@@ -88,6 +88,15 @@ function(var,infile,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
   # get information about variables
 	
   varnames <- names(id$var)
+  var_default <- subset(varnames, !(varnames %in% c("lat","lon","time_bnds","nb2","time")))
+  
+  if (toupper(var) %in% toupper(var_default)){
+    var <- var_default[which(toupper(var)==toupper(var_default))]
+  } else {
+      cat("Variable ",var," not found.",sep="","\n")
+      var <- var_default[1]
+      cat("Variable ",var," will be used.",sep="","\n")
+    }
   
     # set variable precision 
     varind   <- which(varnames==var)
@@ -160,6 +169,7 @@ function(var,infile,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
       data1 <- dummy
     }
 
+    cmsaf_info <- (paste("cmsaf::sellonlatbox for variable ",var,sep=""))
     data1[is.na(data1)] <- v_missing_value
     nb2 <- c(0,1)
 
@@ -183,6 +193,7 @@ function(var,infile,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
 
       ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
       ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
+      ncatt_put(ncnew,var,"cmsaf_info",cmsaf_info,prec="text")
 
       ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
       ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -206,6 +217,7 @@ function(var,infile,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
 
       ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
       ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
+      ncatt_put(ncnew,var,"cmsaf_info",cmsaf_info,prec="text")
 
       ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
       ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
