@@ -38,7 +38,7 @@ function(var,year=c(2000),infile,outfile,nc34=3){
    v__FillValue = "undefined"
    v_missing_value = "undefined"
 
-   info = "Created with the CM SAF R toolbox." 
+   info = "Created with the CM SAF R Toolbox." 
    var_prec="float"
 
    att_list <- c("standard_name","long_name","units","_FillValue","missing_value","calendar")
@@ -88,6 +88,15 @@ function(var,year=c(2000),infile,outfile,nc34=3){
   # get information about variables
 	
   varnames <- names(id$var)
+  var_default <- subset(varnames, !(varnames %in% c("lat","lon","time_bnds","nb2","time")))
+  
+  if (toupper(var) %in% toupper(var_default)){
+    var <- var_default[which(toupper(var)==toupper(var_default))]
+  } else {
+      cat("Variable ",var," not found.",sep="","\n")
+      var <- var_default[1]
+      cat("Variable ",var," will be used.",sep="","\n")
+    }
   
     # set variable precision 
     varind   <- which(varnames==var)
@@ -106,14 +115,14 @@ function(var,year=c(2000),infile,outfile,nc34=3){
 	      assign(v_att_list[i],att_dum$value)}
     }
 
-      # get details of file
+    # get details of file
 
-	lon <- ncvar_get(id,lon_name)
-	lat <- ncvar_get(id,lat_name)
-	time1 <- ncvar_get(id,t_name)
-	if ("time_bnds" %in% varnames){
-	  tbnds1 <- ncvar_get(id,"time_bnds",collapse_degen=FALSE)
-	}
+	  lon <- ncvar_get(id,lon_name)
+	  lat <- ncvar_get(id,lat_name)
+	  time1 <- ncvar_get(id,t_name)
+	  if ("time_bnds" %in% varnames){
+	    tbnds1 <- ncvar_get(id,"time_bnds",collapse_degen=FALSE)
+	  }
    }else{
       nc_close(id)
       stop(cat(paste("Variable ",var," not found! File contains: ",varnames,sep="")),"\n")}
@@ -155,6 +164,7 @@ function(var,year=c(2000),infile,outfile,nc34=3){
     compression = NA
   }
 
+    cmsaf_info <- (paste("cmsaf::selyear for variable ",var,sep=""))
     target[is.na(target)] <- v_missing_value
 
     nb2 <- c(0,1)
@@ -179,6 +189,7 @@ function(var,year=c(2000),infile,outfile,nc34=3){
 
       ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
       ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
+      ncatt_put(ncnew,var,"cmsaf_info",cmsaf_info,prec="text")
 
       ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
       ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -202,6 +213,7 @@ function(var,year=c(2000),infile,outfile,nc34=3){
 
       ncatt_put(ncnew,var,"standard_name",v_standard_name,prec="text")
       ncatt_put(ncnew,var,"long_name",v_long_name,prec="text")
+      ncatt_put(ncnew,var,"cmsaf_info",cmsaf_info,prec="text")
 
       ncatt_put(ncnew,"time","standard_name",t_standard_name,prec="text")
       ncatt_put(ncnew,"time","calendar",t_calendar,prec="text")
@@ -225,16 +237,16 @@ function(var,year=c(2000),infile,outfile,nc34=3){
   
       for (i in 1:length(time1)){
        for (j in 1:length(year)){
-	if (years[i]==year[j]){
-	  dum_dat <- ncvar_get(id,var,start=c(1,1,i),count=c(-1,-1,1))
-	  dum_dat[is.na(dum_dat)] <- v_missing_value
-	  ncvar_put(ncnew,var1,dum_dat,start=c(1,1,count),count=c(-1,-1,1))
-	  ncvar_put(ncnew,t,time1[i], start=count, count=1)
-	  if ("time_bnds" %in% varnames){
-	    ncvar_put(ncnew,var2,tbnds1[,i],start=c(1,count),count=c(-1,1))
-	  }
-	  count <- count+1
-	}
+	      if (years[i]==year[j]){
+	        dum_dat <- ncvar_get(id,var,start=c(1,1,i),count=c(-1,-1,1))
+	        dum_dat[is.na(dum_dat)] <- v_missing_value
+	        ncvar_put(ncnew,var1,dum_dat,start=c(1,1,count),count=c(-1,-1,1))
+	        ncvar_put(ncnew,t,time1[i], start=count, count=1)
+	        if ("time_bnds" %in% varnames){
+	          ncvar_put(ncnew,var2,tbnds1[,i],start=c(1,count),count=c(-1,1))
+	        }
+	      count <- count+1
+	      }
        }
       }
       nc_close(id)
